Subscribing
===========

.. important:: *Terminus GPS Notifications* charges an one-time set-up fee (**$140.00**) for new users.

   After paying the set-up fee, you will be charged a service fee (**$60.00**) every month thereafter.

   **Prices specified in this document are not consistently verified for accuracy.**

.. seealso:: `Your subscription page <https://api.terminusgps.com/subscription/>`_ for up-to-date pricing information.

1. :doc:`Login <logging_in>` to the *Terminus GPS Notifications* platform.

2. Navigate to the `account`_ page.

3. Add a payment method to your account.

4. Add a shipping address to your account.

5. Navigate to the `subscription`_ page.

6. Select your desired payment method and shipping address.

7. Click the *Subscribe* button. This action **will charge the card you specified in the previous step**.

After subscribing, your `dashboard`_ will be updated to reflect your active subscription.

.. _account: https://api.terminusgps.com/account/
.. _dashboard: https://api.terminusgps.com/dashboard/
.. _subscription: https://api.terminusgps.com/subscription/
